@@ -1,3 +1,18 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 """
 Generates test cases to verify the event analytics logs.
 """
@@ -49,13 +64,14 @@ class ReqsTestGenerator(object):
             yield from self.generate_cim_req_params()
 
     # Extract key values pair XML
-    def extract_key_value_xml(self, event):
+    def extract_key_value_xml(self, event, type):
         key_value_dict = keyValue()
-        for fields in event.iter("field"):
-            if fields.get("name"):
-                field_name = fields.get("name")
-                field_value = fields.get("value")
-                key_value_dict.add(field_name, field_value)
+        for type_fields in event.iter(type):
+            for fields in type_fields.iter("field"):
+                if fields.get("name"):
+                    field_name = fields.get("name")
+                    field_value = fields.get("value")
+                    key_value_dict.add(field_name, field_value)
         # self.logger.info(key_value_dict)
         return key_value_dict
 
@@ -97,7 +113,7 @@ class ReqsTestGenerator(object):
         """
         req_file_path = self.folder_path
         req_test_id = 0
-        modinput_params = None
+        transport_type_params = None
         if os.path.isdir(req_file_path):
             for file1 in os.listdir(req_file_path):
                 filename = os.path.join(req_file_path, file1)
@@ -134,26 +150,36 @@ class ReqsTestGenerator(object):
                             "dbx",
                             "windows_input",
                             "hec_event",
+                            "scripted_input",
+                            "scripted input",
+                            "hec_raw",
+                            "file_monitor",
+                            "forwarder",
                         ):
                             host, source, sourcetype = self.extract_params(event_tag)
                             host, source, sourcetype = self.escape_host_src_srctype(
                                 host, source, sourcetype
                             )
-                            modinput_params = {
+                            transport_type_params = {
                                 "host": host,
                                 "source": source,
                                 "sourcetype": sourcetype,
                             }
-
                         else:
-                            # todo: non syslog/modinput events are skipped currently until we support it
+                            # todo: non syslog/modinput/non forwarder/scripted_input events are skipped currently until we support it
                             continue
 
                         escaped_event = self.escape_char_event(unescaped_event)
                         model_list = self.get_models(event_tag)
                         # Fetching kay value pair from XML
-                        key_value_dict = self.extract_key_value_xml(event_tag)
-                        # self.logger.info(key_value_dict)
+                        key_value_dict = self.extract_key_value_xml(
+                            event_tag, "cim_fields"
+                        )
+                        exceptions_dict = self.extract_key_value_xml(
+                            event_tag, "exceptions"
+                        )
+                        self.logger.info(key_value_dict)
+                        self.logger.info(exceptions_dict)
                         if len(model_list) == 0:
                             LOGGER.info("No model in this event")
                             continue
@@ -170,8 +196,9 @@ class ReqsTestGenerator(object):
                                 "model_list": list_model_dataset_subdataset,
                                 "escaped_event": escaped_event,
                                 "Key_value_dict": key_value_dict,
-                                "modinput_params": modinput_params,
+                                "modinput_params": transport_type_params,
                                 "transport_type": transport_type,
+                                "exceptions_dict": exceptions_dict,
                             },
                             id=f"{(' '.join(model_list))}::{filename}::event_no::{event_no}",
                         )
@@ -295,7 +322,13 @@ class ReqsTestGenerator(object):
             "LIKE",
         ]
         event = event.replace("\\", "\\\\")
+        bounded_asterisk = re.search(
+            r"\"[\s*\w*\.\-\,\\\?\_\]\[\']*\*+[\s*\w*\.\-\,\\\?\_\[\]\']*\"", event
+        )
+        if bounded_asterisk:
+            event = event.replace("*", "\\*")
+        else:
+            event = event.replace("*", " ")
         for character in escape_splunk_chars:
             event = event.replace(character, "\\" + character)
-        event = event.replace("*", " ")
         return event
