@@ -1,3 +1,19 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+import json
 import logging
 import pytest
 import re
@@ -28,14 +44,22 @@ class ReqsTestTemplates(object):
         return new_dict
 
     # Function to compare the fields extracted from XML and the fields extracted from Splunk search
-    def compare(self, keyValueSPL, keyValueXML):
+    def compare(self, keyValueSPL, keyValueXML, escapedKeyValue):
         dict_missing_key_value = {}
         keyValueprocessedSPL = self.process_str(keyValueSPL)
         flag = True
         for key, value in keyValueXML.items():
             res = key in keyValueprocessedSPL and value == keyValueprocessedSPL[key]
-            if not res:
-                dict_missing_key_value.update({key: value})
+            if (not res) and (key not in escapedKeyValue):
+                valueinsplunk = None
+                if key in keyValueSPL.keys():
+                    valueinsplunk = keyValueSPL[key]
+                dict_missing_key_value.update(
+                    {
+                        "Key value in requirement file: " + key: value,
+                        "Key value extracted by Splunk: " + key: valueinsplunk,
+                    }
+                )
                 flag = False
         return flag, dict_missing_key_value
 
@@ -125,8 +149,10 @@ class ReqsTestTemplates(object):
         model_datalist = splunk_searchtime_requirement_param["model_list"]
         escaped_event = splunk_searchtime_requirement_param["escaped_event"]
         key_values_xml = splunk_searchtime_requirement_param["Key_value_dict"]
+        exceptions_dict = splunk_searchtime_requirement_param["exceptions_dict"]
         modinput_params = splunk_searchtime_requirement_param["modinput_params"]
         transport_type = splunk_searchtime_requirement_param["transport_type"]
+        logging.info(exceptions_dict)
         # search = f" search source= pytest_splunk_addon:hec:raw sourcetype={sourcetype} {escaped_event} |fields * "
         # removed source and sourcetype as sc4s assigns it based on event
         if transport_type in (
@@ -173,14 +199,9 @@ class ReqsTestTemplates(object):
         self.logger.info(f"Data model check: {datamodel_check}")
         sourcetype = keyValue_dict_SPL["_sourcetype"]
         field_extraction_check, missing_key_value = self.compare(
-            keyValue_dict_SPL, key_values_xml
+            keyValue_dict_SPL, key_values_xml, exceptions_dict
         )
         self.logger.info(f"Field mapping check: {field_extraction_check}")
-        mismapped_key_value_pair = {}
-        for key, value in missing_key_value.items():
-            if key in keyValue_dict_SPL.keys():
-                valueInSplunk = keyValue_dict_SPL[key]
-                mismapped_key_value_pair.update({key: valueInSplunk})
 
         assert datamodel_check and field_extraction_check, (
             f" Issue with either field extraction or data model.\nsearch={search}\n"
@@ -188,7 +209,6 @@ class ReqsTestTemplates(object):
             f" data model in requirement file  {model_datalist}\n "
             f" data model extracted by TA {list(datamodel_based_on_tag.keys())}\n"
             f" Field_extraction_check: {field_extraction_check} \n"
-            f" Key value not extracted by TA: {missing_key_value} \n"
-            f" Mismatched key value: {mismapped_key_value_pair}\n"
+            f" Field extraction errors: {json.dumps(missing_key_value, indent=4)} \n"
             f" sourcetype of ingested event: {sourcetype} \n"
         )
